#!/opt/cloudlinux/venv/bin/python3

# Copyright (c) Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2018 All Rights Reserved
#
# Licensed under CLOUD LINUX LICENSE AGREEMENT
# http://cloudlinux.com/docs/LICENSE.TXT

import os
import getopt
import sys
from lve_diagnostic import get_cp
from exec_command import exec_command_out
from common import is_ubuntu


SOURCE = "/usr/share/lve/modlscapi/"


def install_mod_lsapi_for_ubuntu():
    """Install mod_lsapi for Ubuntu"""
    exec_command_out(SOURCE + "utils/standard-install-modlsapi apache2")
    exec_command_out('a2enmod lsapi')
    exec_command_out('systemctl restart apache2')


def install_mod_lsapi_for_cl(cp):
    """Install mod_lsapi for CloudLinux"""
    if cp.name == "cPanel":
        # install mod_lsapi for CPanel
        exec_command_out(SOURCE + "utils/cpanel-make-lve")
        exec_command_out(SOURCE + "utils/cpanel-hooks-lve")
        exec_command_out(SOURCE + "hooks/cpanelpostupcp.hook")
    elif cp.name != "DirectAdmin":
        # install mod_lsapi for pure system
        exec_command_out(SOURCE + "utils/standard-install-modlsapi httpd")


def install_mod_lsapi(cp):
    """Generic function to install mod_lsapi.
    This function will detect os and choose appropriate function.
    """
    if is_ubuntu():
        install_mod_lsapi_for_ubuntu()
    else:
        install_mod_lsapi_for_cl(cp)


def delete_mod_lsapi_for_ubuntu():
    """Delete mod_lsapi for Ubuntu"""
    exec_command_out('a2dismod lsapi')
    exec_command_out('systemctl restart apache2')


def delete_mod_lsapi_for_cl(cp):
    """Delete mod_lsapi for CloudLinux"""
    if cp.name == "cPanel":
        # delete mod_lsapi for CPanel
        if os.path.exists(SOURCE + "utils/cpanel-delete-lve"):
            exec_command_out(SOURCE + "utils/cpanel-delete-lve")
    elif cp.name != "DirectAdmin":
        # delete mod_lsapi for pure system
        if os.path.exists(SOURCE + "utils/standard-delete-modlsapi"):
            exec_command_out(SOURCE + "utils/standard-delete-modlsapi httpd")


def delete_mod_lsapi(cp):
    """Generic function to delete mod_lsapi.
    This function will detect os and choose appropriate function.
    """
    if is_ubuntu():
        delete_mod_lsapi_for_ubuntu()
    else:
        delete_mod_lsapi_for_cl(cp)


def usage():
    print('')
    print('Use following syntax to manage mod_lsapi istall utility:')
    print(sys.argv[0]+" [OPTIONS]")
    print('Options:')
    print(" -i | --install : install mod_lsapi")
    print(" -d | --delete : install mod_lsapi")


def main():
    cp = get_cp()
    try:
        opts, args = getopt.getopt(sys.argv[1:], "hid", ["help", "install", "delete"])
    except getopt.GetoptError as err:
        # print help information and exit:
        print(str(err))  # will print something like "option -a not recognized"
        usage()
        sys.exit(2)

    for o, a in opts:
        if o in ("-h", "--help"):
            usage()
            sys.exit()
        elif o in ("-i", "--install"):
            install_mod_lsapi(cp)
        elif o in ("-d", "--delete"):
            delete_mod_lsapi(cp)
        else:
            usage()
            sys.exit(2)


if __name__ == '__main__':
    main()
