#!/bin/bash
# Copyright © Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2021 All Rights Reserved
#
# Licensed under CLOUD LINUX LICENSE AGREEMENT
# http://cloudlinux.com/docs/LICENSE.TXT

# Note: Also called from Debian
# Arguments:

# RPM
# $1 == 1 - install package
# $1 == 2 - upgrade package

# DEB
# $1 == configure - RPM post/posttrans

# "mod_lsapi POST TRANS STARTED"
g_path=/usr/share/lve/modlscapi/
rhel=$2
is_ubuntu=$3

"${g_path}"user/install-mod_lsapi.py --install

if [ -x /usr/local/psa ]; then
  PLESK_LSAPI_HOOK="${g_path}hooks/plesk_update_hook.py"
  if ! plesk bin event_handler -l 2>/dev/null | grep -q "${PLESK_LSAPI_HOOK}"
  then
      echo "Try to register update event handler..."
      plesk bin event_handler --create -command "${PLESK_LSAPI_HOOK}" -priority 100 -user root -event plesk_component_upgrade
      if [ $? != 0 ]; then
          echo "Old Plesk version, try to register event handler by ID"
          plesk bin event_handler --create -command "${PLESK_LSAPI_HOOK}" -priority 100 -user root -event 70
      fi
  else
      echo "Update event handler is already registered"
  fi
fi

echo "Restarting apache for new mod_lsapi..."

if [[ $is_ubuntu == "true" ]]; then
  systemctl restart apache2
elif [[ $rhel -lt 7 ]]; then
  /sbin/service httpd restart
else
  systemctl restart httpd.service
fi

if [[ $is_ubuntu == "true" ]]; then
  cat > /etc/container/php.handler <<EOF
application/x-lsphp52 /opt/alt/php52/usr/bin/lsphp
application/x-lsphp53 /opt/alt/php53/usr/bin/lsphp
application/x-lsphp54 /opt/alt/php54/usr/bin/lsphp
application/x-lsphp55 /opt/alt/php55/usr/bin/lsphp
application/x-lsphp56 /opt/alt/php56/usr/bin/lsphp
application/x-lsphp70 /opt/alt/php70/usr/bin/lsphp
application/x-lsphp71 /opt/alt/php71/usr/bin/lsphp
application/x-lsphp72 /opt/alt/php72/usr/bin/lsphp
application/x-lsphp73 /opt/alt/php73/usr/bin/lsphp
application/x-lsphp74 /opt/alt/php74/usr/bin/lsphp
application/x-lsphp80 /opt/alt/php80/usr/bin/lsphp
application/x-lsphp81 /opt/alt/php81/usr/bin/lsphp
application/x-lsphp82 /opt/alt/php82/usr/bin/lsphp
application/x-lsphp83 /opt/alt/php83/usr/bin/lsphp
EOF
fi 

# "mod_lsapi POST TRANS FINISHED"
exit 0
